@@ -81,10 +81,10 @@ def template(ctx, taskKey):
         account._noLoginMessage()
 
     if taskKey == "":
-        print(" you should specify which key you'd like to export, command:\n")
-        print("  tla template <taskKey> \n")
-        print(" more about this command, use：\n")
-        print("  tla config --help")
+        click.echo(" you should specify which key you'd like to export, command:\n")
+        click.echo("  tla template -k <taskKey> \n")
+        click.echo(" more about this command, use：\n")
+        click.echo("  tla config --help")
         exit()
 
     codeContent=f"""from testinlabel.exportAbstract import ExportAbstract # warning: don't edit this line !!!
@@ -119,18 +119,25 @@ def export(ctx, file):
     """ exec export """
 
     if file == "":
-        print(" you should specify where the script is, command:\n")
-        print("  tla export <scriptPath> \n")
-        print(" you need generate export code template before export, use:\n")
-        print("  tla template <taskKey> \n")
-        print(" more about this command, use：\n")
-        print("  tla export --help")
+        click.echo(" you need specify where the script is, command:\n")
+        click.echo("  tla export -f <scriptPath> \n")
+        click.echo(" you need generate export code template before export, use:\n")
+        click.echo("  tla template -k <taskKey> \n")
+        click.echo(" more about this command, use：\n")
+        click.echo("  tla export --help")
         exit()
 
     if ctx.obj == None:
         account._noLoginMessage()
     try:
-        sys.path.append(os.path.split(file)[0])
+        scriptPath = os.path.split(file)[0]
+        if scriptPath == "":
+            scriptPath = os.getcwd()
+
+        print(os.path.abspath('.'))
+        print(scriptPath)
+        exit()
+        sys.path.append(scriptPath)
         from export import Export
         ex = Export(ctx.obj)
         ex.exec()
